@@ -23,11 +23,11 @@ TRACKING_CODE = """
       var s = document.createElement('script');
       s.type = 'text/javascript';
       s.async = true;
-      s.src = ( document.location.protocol == 'https:' ? 'https://static.getclicky.com/js' : 'http://static.getclicky.com/js' );
+      s.src = '//static.getclicky.com/js';
       ( document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0] ).appendChild( s );
     })();
     </script>
-    <noscript><p><img alt="Clicky" width="1" height="1" src="http://in.getclicky.com/%(site_id)sns.gif" /></p></noscript>
+    <noscript><p><img alt="Clicky" width="1" height="1" src="//in.getclicky.com/%(site_id)sns.gif" /></p></noscript>
 """
 
 
